@@ -6,23 +6,13 @@
  * Date        : 2018-07-30
  * Description : action container for external plugin
  *
- * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DPLUGIN_ACTION_H
-#define DIGIKAM_DPLUGIN_ACTION_H
+#pragma once
 
 // Qt includes
 
@@ -70,10 +60,17 @@ public:
         EditorFilters           ///< Image Editor special effects action.
     };
 
+    /// Plugin action types via QAction data container.
+    enum PluginActionData
+    {
+        NoData        = 0,
+        AlbumData
+    };
+
 public:
 
     explicit DPluginAction(QObject* const parent = nullptr);
-    ~DPluginAction() override;
+    ~DPluginAction() override = default;
 
     /**
      * Manage the internal action category.
@@ -107,5 +104,3 @@ public:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DPLUGIN_ACTION_H
