@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
  * SPDX-FileCopyrightText: 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -56,13 +56,13 @@ class ThumbnailIdentifier;
 class ThumbnailInfo;
 
 /**
- * The ItemInfo class contains provides access to the database for a single image.
- * The properties can be read and written. Information will be cached.
+ * @brief The ItemInfo class contains provides access to the database for a single image.
+ *        The properties can be read and written. Information will be cached.
  *
- * NOTE: access rules for all methods in this class:
- * ItemInfoData members shall be accessed only under CoreDbAccess lock.
- * The id and albumId are the exception to this rule, as they are
- * primitive and will never change during the lifetime of an object.
+ * @note access rules for all methods in this class:
+ *       ItemInfoData members shall be accessed only under CoreDbAccess lock.
+ *       The id and albumId are the exception to this rule, as they are
+ *       primitive and will never change during the lifetime of an object.
  */
 class DIGIKAM_DATABASE_EXPORT ItemInfo
 {
@@ -639,8 +639,17 @@ public:
     /**
      * Return a signature for the item.
      */
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    size_t hash()                                                                       const;
+
+#else
+
     uint hash()                                                                         const;
 
+#endif
+
     /**
      * Scans the database for items with the given signature.
      */
@@ -661,7 +670,16 @@ private:
     QExplicitlySharedDataPointer<ItemInfoData> m_data;
 };
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+inline size_t qHash(const ItemInfo& info)
+
+#else
+
 inline uint qHash(const ItemInfo& info)
+
+#endif
+
 {
     return info.hash();
 }
